@@ -2,6 +2,7 @@ from braintree.add_on import AddOn
 from braintree.add_on_gateway import AddOnGateway
 from braintree.address import Address
 from braintree.address_gateway import AddressGateway
+from braintree.apple_pay_card import ApplePayCard
 from braintree.braintree_gateway import BraintreeGateway
 from braintree.client_token import ClientToken
 from braintree.configuration import Configuration
@@ -46,6 +47,7 @@ from braintree.disbursement import Disbursement
 from braintree.subscription_search import SubscriptionSearch
 from braintree.successful_result import SuccessfulResult
 from braintree.transaction_amounts import TransactionAmounts
+from braintree.transaction_details import TransactionDetails
 from braintree.transparent_redirect import TransparentRedirect
 from braintree.transparent_redirect_gateway import TransparentRedirectGateway
 from braintree.validation_error_collection import ValidationErrorCollection
