@@ -2,6 +2,7 @@ import braintree
 import warnings
 from decimal import Decimal
 from braintree.add_on import AddOn
+from braintree.apple_pay_card import ApplePayCard
 from braintree.disbursement_detail import DisbursementDetail
 from braintree.dispute import Dispute
 from braintree.discount import Discount
@@ -468,6 +469,8 @@ class Transaction(Resource):
             self.paypal_details = PayPalAccount(gateway, attributes.pop("paypal"))
         if "sepa_bank_account" in attributes:
             self.sepa_bank_account_details = SEPABankAccount(gateway, attributes.pop("sepa_bank_account"))
+        if "apple_pay" in attributes:
+            self.apple_pay_details = ApplePayCard(gateway, attributes.pop("apple_pay"))
         if "customer" in attributes:
             self.customer_details = Customer(gateway, attributes.pop("customer"))
         if "shipping" in attributes:
